from __future__ import print_function
import logging
import numpy

import grpc

from . import uda_pb2
from . import uda_pb2_grpc

class UDA(object):
    def __init__(self, host='127.0.0.1', port=50051) -> None:
        super().__init__()
        logging.basicConfig()
        self._host = host
        self._port = str(port)
        self.channel = grpc.insecure_channel(target = self._host + ':' + self._port,
                                             options=[('grpc.lb_policy_name', 'pick_first'),
                                                      ('grpc.enable_retries', 0),
                                                      ('grpc.keepalive_timeout_ms', 10000)
                                                      ])
        self.experiment_stub = uda_pb2_grpc.ExperimentStub(self.channel)
        self.meta_stub = uda_pb2_grpc.MetaStub(self.channel)
        self.user_stub = uda_pb2_grpc.UserStub(self.channel)
        self.project_stub = uda_pb2_grpc.ProjectStub(self.channel)
        self.token = ''
    
    def Signal(self, exp, path, shot):
        signalrequest = uda_pb2.SignalRequest()
        signalrequest.experiment = exp
        signalrequest.path = path
        signalrequest.shot = shot
        signalresponse = self.experiment_stub.Signal(signalrequest, timeout = 30)
        return numpy.frombuffer(signalresponse.data, dtype=numpy.float32)

    def SignalByTime(self, exp, path, shot, start, end):
        sginaldatabytimerequest = uda_pb2.SignalByTimeRequest()
        sginaldatabytimerequest.experiment = exp
        sginaldatabytimerequest.path = path
        sginaldatabytimerequest.shot = shot
        sginaldatabytimerequest.start = start
        sginaldatabytimerequest.end = end
        signaldatabytimeresponse = self.experiment_stub.SignalByTime(sginaldatabytimerequest, timeout=30)
        return numpy.frombuffer(signaldatabytimeresponse.data, dtype=numpy.float32)

    def SignalList(self, exp):
        signallistrequest = uda_pb2.SignalListRequest()
        signallistrequest.experiment = exp;
        signallistresponse = self.meta_stub.SignalList(signallistrequest, timeout = 30)
        return signallistresponse.item

    def SignalMeta(self, exp, path, shot):
        singalmetarequest = uda_pb2.SignalMetaRequest()
        singalmetarequest.experiment = exp
        singalmetarequest.path = path
        singalmetarequest.shot = shot
        signalmetaresponse = self.meta_stub.SingalMeta(singalmetarequest, timeout = 30)
        return signalmetaresponse.details

    def SignalMonitor(self):
        empty = uda_pb2.Empty()
        signalmonitorresponse = self.project_stub.SignalMonitor(empty, timeout = 30)
        return signalmonitorresponse

    def SignalMonitorByTime(self, system, name, start, end):
        signalmonitorbytimerequest = uda_pb2.SignalMonitorByTimeRequest()
        signalmonitorbytimerequest.system = system;
        signalmonitorbytimerequest.name = name
        signalmonitorbytimerequest.start = start
        signalmonitorbytimerequest.end = end
        signalmonitorbytimeresponse = self.project_stub.SignalMonitorByTime(signalmonitorbytimerequest, timeout = 30)
        return signalmonitorbytimeresponse.data

    def SignalMonitorStruct(self):
        empty = uda_pb2.Empty()
        signalmonitorrequest = self.project_stub.SignalMonitorStruct(empty, timeout = 30)
        return signalmonitorrequest.item

    def Login(self, username, password) -> bool:
        loginrequest = uda_pb2.LoginRequest()
        loginrequest.username = username
        loginrequest.password = password
        loginreponse = self.user_stub.Login(loginrequest, timeout=30)
        self.token = loginreponse.token
        if self.token == '' or self.token.uda_pb2.Empty():
            return False
        return True





# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: uda.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='uda.proto',
  package='uda',
  syntax='proto3',
  serialized_options=b'\n\rcn.ac.ipp.udaB\003UDAP\001\242\002\003UDA',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\tuda.proto\x12\x03uda\"?\n\rSignalRequest\x12\x12\n\nexperiment\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x0c\n\x04shot\x18\x03 \x01(\x05\"a\n\x0eSignalResponse\x12\x12\n\nexperiment\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x0c\n\x04shot\x18\x03 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x0c\x12\x11\n\tdata_size\x18\x05 \x01(\x05\"a\n\x13SignalByTimeRequest\x12\x12\n\nexperiment\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x0c\n\x04shot\x18\x03 \x01(\x05\x12\r\n\x05start\x18\x04 \x01(\x01\x12\x0b\n\x03\x65nd\x18\x05 \x01(\x01\"\x83\x01\n\x14SignalByTimeResponse\x12\x12\n\nexperiment\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x0c\n\x04shot\x18\x03 \x01(\x05\x12\r\n\x05start\x18\x04 \x01(\x01\x12\x0b\n\x03\x65nd\x18\x05 \x01(\x01\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\x0c\x12\x11\n\tdata_size\x18\x07 \x01(\x05\"\'\n\x11SignalListRequest\x12\x12\n\nexperiment\x18\x01 \x01(\t\";\n\x0eSignalListItem\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\r\n\x05usage\x18\x03 \x01(\t\"K\n\x12SignalListResponse\x12\x12\n\nexperiment\x18\x01 \x01(\t\x12!\n\x04item\x18\x02 \x03(\x0b\x32\x13.uda.SignalListItem\"C\n\x11SignalMetaRequest\x12\x12\n\nexperiment\x18\x01 \x01(\t\x12\x0c\n\x04shot\x18\x02 \x01(\x05\x12\x0c\n\x04path\x18\x03 \x01(\t\"\xd3\x01\n\x0cSignalDetail\x12\x12\n\ncreateTime\x18\x01 \x01(\t\x12\x0f\n\x07\x64\x61qTime\x18\x02 \x01(\x01\x12\x0c\n\x04\x66req\x18\x03 \x01(\x05\x12\x0e\n\x06\x66trans\x18\x04 \x01(\x01\x12\r\n\x05\x66zero\x18\x05 \x01(\x01\x12\r\n\x05\x66zoom\x18\x06 \x01(\x01\x12\x0e\n\x06segNum\x18\x07 \x01(\x05\x12\x0f\n\x07segTime\x18\x08 \x01(\x01\x12\x0f\n\x07sigUnit\x18\t \x01(\t\x12\x10\n\x08trigTime\x18\n \x01(\x01\x12\r\n\x05uIMax\x18\x0b \x01(\x05\x12\x0f\n\x07uISwing\x18\x0c \x01(\x05\"h\n\x12SignalMetaResponse\x12\x12\n\nexperiment\x18\x01 \x01(\t\x12\x0c\n\x04shot\x18\x02 \x01(\x05\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\"\n\x07\x64\x65tails\x18\x04 \x03(\x0b\x32\x11.uda.SignalDetail\"\x07\n\x05\x45mpty\"6\n\x11SignalMonitorItem\x12\x0f\n\x07signame\x18\x01 \x01(\t\x12\x10\n\x08sigvalue\x18\x02 \x01(\t\"=\n\x15SignalMonitorResponse\x12$\n\x04item\x18\x01 \x03(\x0b\x32\x16.uda.SignalMonitorItem\"V\n\x1aSignalMonitorByTimeRequest\x12\x0e\n\x06system\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05start\x18\x03 \x01(\t\x12\x0b\n\x03\x65nd\x18\x04 \x01(\t\"e\n\x1bSignalMonitorByTimeResponse\x12\x0e\n\x06system\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05start\x18\x03 \x01(\t\x12\x0b\n\x03\x65nd\x18\x04 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x05 \x03(\x02\"Q\n\x18SignalMonitorTableColumn\x12\x12\n\ncolumnname\x18\x01 \x01(\t\x12\x10\n\x08\x64\x61tatype\x18\x02 \x01(\t\x12\x0f\n\x07\x63omment\x18\x03 \x01(\t\"X\n\x17SignalMonitorStructItem\x12\x0e\n\x06system\x18\x01 \x01(\t\x12-\n\x06\x63olumn\x18\x02 \x03(\x0b\x32\x1d.uda.SignalMonitorTableColumn\"I\n\x1bSignalMonitorStructResponse\x12*\n\x04item\x18\x01 \x03(\x0b\x32\x1c.uda.SignalMonitorStructItem\"2\n\x0cLoginRequest\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\",\n\rLoginResponse\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t2\x88\x01\n\nExperiment\x12\x33\n\x06Signal\x12\x12.uda.SignalRequest\x1a\x13.uda.SignalResponse\"\x00\x12\x45\n\x0cSignalByTime\x12\x18.uda.SignalByTimeRequest\x1a\x19.uda.SignalByTimeResponse\"\x00\x32\x88\x01\n\x04Meta\x12?\n\nSignalList\x12\x16.uda.SignalListRequest\x1a\x17.uda.SignalListResponse\"\x00\x12?\n\nSingalMeta\x12\x16.uda.SignalMetaRequest\x1a\x17.uda.SignalMetaResponse\"\x00\x32\xe7\x01\n\x07Project\x12\x39\n\rSignalMonitor\x12\n.uda.Empty\x1a\x1a.uda.SignalMonitorResponse\"\x00\x12Z\n\x13SignalMonitorByTime\x12\x1f.uda.SignalMonitorByTimeRequest\x1a .uda.SignalMonitorByTimeResponse\"\x00\x12\x45\n\x13SignalMonitorStruct\x12\n.uda.Empty\x1a .uda.SignalMonitorStructResponse\"\x00\x32\x38\n\x04User\x12\x30\n\x05Login\x12\x11.uda.LoginRequest\x1a\x12.uda.LoginResponse\"\x00\x42\x1c\n\rcn.ac.ipp.udaB\x03UDAP\x01\xa2\x02\x03UDAb\x06proto3'
)




_SIGNALREQUEST = _descriptor.Descriptor(
  name='SignalRequest',
  full_name='uda.SignalRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiment', full_name='uda.SignalRequest.experiment', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='uda.SignalRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shot', full_name='uda.SignalRequest.shot', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18,
  serialized_end=81,
)


_SIGNALRESPONSE = _descriptor.Descriptor(
  name='SignalResponse',
  full_name='uda.SignalResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiment', full_name='uda.SignalResponse.experiment', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='uda.SignalResponse.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shot', full_name='uda.SignalResponse.shot', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='uda.SignalResponse.data', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_size', full_name='uda.SignalResponse.data_size', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=83,
  serialized_end=180,
)


_SIGNALBYTIMEREQUEST = _descriptor.Descriptor(
  name='SignalByTimeRequest',
  full_name='uda.SignalByTimeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiment', full_name='uda.SignalByTimeRequest.experiment', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='uda.SignalByTimeRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shot', full_name='uda.SignalByTimeRequest.shot', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start', full_name='uda.SignalByTimeRequest.start', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end', full_name='uda.SignalByTimeRequest.end', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=182,
  serialized_end=279,
)


_SIGNALBYTIMERESPONSE = _descriptor.Descriptor(
  name='SignalByTimeResponse',
  full_name='uda.SignalByTimeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiment', full_name='uda.SignalByTimeResponse.experiment', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='uda.SignalByTimeResponse.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shot', full_name='uda.SignalByTimeResponse.shot', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start', full_name='uda.SignalByTimeResponse.start', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end', full_name='uda.SignalByTimeResponse.end', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='uda.SignalByTimeResponse.data', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_size', full_name='uda.SignalByTimeResponse.data_size', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=282,
  serialized_end=413,
)


_SIGNALLISTREQUEST = _descriptor.Descriptor(
  name='SignalListRequest',
  full_name='uda.SignalListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiment', full_name='uda.SignalListRequest.experiment', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=415,
  serialized_end=454,
)


_SIGNALLISTITEM = _descriptor.Descriptor(
  name='SignalListItem',
  full_name='uda.SignalListItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='uda.SignalListItem.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='uda.SignalListItem.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usage', full_name='uda.SignalListItem.usage', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=456,
  serialized_end=515,
)


_SIGNALLISTRESPONSE = _descriptor.Descriptor(
  name='SignalListResponse',
  full_name='uda.SignalListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiment', full_name='uda.SignalListResponse.experiment', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='item', full_name='uda.SignalListResponse.item', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=517,
  serialized_end=592,
)


_SIGNALMETAREQUEST = _descriptor.Descriptor(
  name='SignalMetaRequest',
  full_name='uda.SignalMetaRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiment', full_name='uda.SignalMetaRequest.experiment', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shot', full_name='uda.SignalMetaRequest.shot', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='uda.SignalMetaRequest.path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=594,
  serialized_end=661,
)


_SIGNALDETAIL = _descriptor.Descriptor(
  name='SignalDetail',
  full_name='uda.SignalDetail',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='createTime', full_name='uda.SignalDetail.createTime', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='daqTime', full_name='uda.SignalDetail.daqTime', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='freq', full_name='uda.SignalDetail.freq', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ftrans', full_name='uda.SignalDetail.ftrans', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fzero', full_name='uda.SignalDetail.fzero', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fzoom', full_name='uda.SignalDetail.fzoom', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='segNum', full_name='uda.SignalDetail.segNum', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='segTime', full_name='uda.SignalDetail.segTime', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sigUnit', full_name='uda.SignalDetail.sigUnit', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trigTime', full_name='uda.SignalDetail.trigTime', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uIMax', full_name='uda.SignalDetail.uIMax', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uISwing', full_name='uda.SignalDetail.uISwing', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=664,
  serialized_end=875,
)


_SIGNALMETARESPONSE = _descriptor.Descriptor(
  name='SignalMetaResponse',
  full_name='uda.SignalMetaResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiment', full_name='uda.SignalMetaResponse.experiment', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shot', full_name='uda.SignalMetaResponse.shot', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='uda.SignalMetaResponse.path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='details', full_name='uda.SignalMetaResponse.details', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=877,
  serialized_end=981,
)


_EMPTY = _descriptor.Descriptor(
  name='Empty',
  full_name='uda.Empty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=983,
  serialized_end=990,
)


_SIGNALMONITORITEM = _descriptor.Descriptor(
  name='SignalMonitorItem',
  full_name='uda.SignalMonitorItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='signame', full_name='uda.SignalMonitorItem.signame', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sigvalue', full_name='uda.SignalMonitorItem.sigvalue', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=992,
  serialized_end=1046,
)


_SIGNALMONITORRESPONSE = _descriptor.Descriptor(
  name='SignalMonitorResponse',
  full_name='uda.SignalMonitorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='uda.SignalMonitorResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1048,
  serialized_end=1109,
)


_SIGNALMONITORBYTIMEREQUEST = _descriptor.Descriptor(
  name='SignalMonitorByTimeRequest',
  full_name='uda.SignalMonitorByTimeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='system', full_name='uda.SignalMonitorByTimeRequest.system', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='uda.SignalMonitorByTimeRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start', full_name='uda.SignalMonitorByTimeRequest.start', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end', full_name='uda.SignalMonitorByTimeRequest.end', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1111,
  serialized_end=1197,
)


_SIGNALMONITORBYTIMERESPONSE = _descriptor.Descriptor(
  name='SignalMonitorByTimeResponse',
  full_name='uda.SignalMonitorByTimeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='system', full_name='uda.SignalMonitorByTimeResponse.system', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='uda.SignalMonitorByTimeResponse.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start', full_name='uda.SignalMonitorByTimeResponse.start', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end', full_name='uda.SignalMonitorByTimeResponse.end', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='uda.SignalMonitorByTimeResponse.data', index=4,
      number=5, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1199,
  serialized_end=1300,
)


_SIGNALMONITORTABLECOLUMN = _descriptor.Descriptor(
  name='SignalMonitorTableColumn',
  full_name='uda.SignalMonitorTableColumn',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='columnname', full_name='uda.SignalMonitorTableColumn.columnname', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datatype', full_name='uda.SignalMonitorTableColumn.datatype', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='comment', full_name='uda.SignalMonitorTableColumn.comment', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1302,
  serialized_end=1383,
)


_SIGNALMONITORSTRUCTITEM = _descriptor.Descriptor(
  name='SignalMonitorStructItem',
  full_name='uda.SignalMonitorStructItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='system', full_name='uda.SignalMonitorStructItem.system', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='column', full_name='uda.SignalMonitorStructItem.column', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1385,
  serialized_end=1473,
)


_SIGNALMONITORSTRUCTRESPONSE = _descriptor.Descriptor(
  name='SignalMonitorStructResponse',
  full_name='uda.SignalMonitorStructResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='uda.SignalMonitorStructResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1475,
  serialized_end=1548,
)


_LOGINREQUEST = _descriptor.Descriptor(
  name='LoginRequest',
  full_name='uda.LoginRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='uda.LoginRequest.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='uda.LoginRequest.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1550,
  serialized_end=1600,
)


_LOGINRESPONSE = _descriptor.Descriptor(
  name='LoginResponse',
  full_name='uda.LoginResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='uda.LoginResponse.user', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token', full_name='uda.LoginResponse.token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1602,
  serialized_end=1646,
)

_SIGNALLISTRESPONSE.fields_by_name['item'].message_type = _SIGNALLISTITEM
_SIGNALMETARESPONSE.fields_by_name['details'].message_type = _SIGNALDETAIL
_SIGNALMONITORRESPONSE.fields_by_name['item'].message_type = _SIGNALMONITORITEM
_SIGNALMONITORSTRUCTITEM.fields_by_name['column'].message_type = _SIGNALMONITORTABLECOLUMN
_SIGNALMONITORSTRUCTRESPONSE.fields_by_name['item'].message_type = _SIGNALMONITORSTRUCTITEM
DESCRIPTOR.message_types_by_name['SignalRequest'] = _SIGNALREQUEST
DESCRIPTOR.message_types_by_name['SignalResponse'] = _SIGNALRESPONSE
DESCRIPTOR.message_types_by_name['SignalByTimeRequest'] = _SIGNALBYTIMEREQUEST
DESCRIPTOR.message_types_by_name['SignalByTimeResponse'] = _SIGNALBYTIMERESPONSE
DESCRIPTOR.message_types_by_name['SignalListRequest'] = _SIGNALLISTREQUEST
DESCRIPTOR.message_types_by_name['SignalListItem'] = _SIGNALLISTITEM
DESCRIPTOR.message_types_by_name['SignalListResponse'] = _SIGNALLISTRESPONSE
DESCRIPTOR.message_types_by_name['SignalMetaRequest'] = _SIGNALMETAREQUEST
DESCRIPTOR.message_types_by_name['SignalDetail'] = _SIGNALDETAIL
DESCRIPTOR.message_types_by_name['SignalMetaResponse'] = _SIGNALMETARESPONSE
DESCRIPTOR.message_types_by_name['Empty'] = _EMPTY
DESCRIPTOR.message_types_by_name['SignalMonitorItem'] = _SIGNALMONITORITEM
DESCRIPTOR.message_types_by_name['SignalMonitorResponse'] = _SIGNALMONITORRESPONSE
DESCRIPTOR.message_types_by_name['SignalMonitorByTimeRequest'] = _SIGNALMONITORBYTIMEREQUEST
DESCRIPTOR.message_types_by_name['SignalMonitorByTimeResponse'] = _SIGNALMONITORBYTIMERESPONSE
DESCRIPTOR.message_types_by_name['SignalMonitorTableColumn'] = _SIGNALMONITORTABLECOLUMN
DESCRIPTOR.message_types_by_name['SignalMonitorStructItem'] = _SIGNALMONITORSTRUCTITEM
DESCRIPTOR.message_types_by_name['SignalMonitorStructResponse'] = _SIGNALMONITORSTRUCTRESPONSE
DESCRIPTOR.message_types_by_name['LoginRequest'] = _LOGINREQUEST
DESCRIPTOR.message_types_by_name['LoginResponse'] = _LOGINRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SignalRequest = _reflection.GeneratedProtocolMessageType('SignalRequest', (_message.Message,), {
  'DESCRIPTOR' : _SIGNALREQUEST,
  '__module__' : 'uda_pb2'
  # @@protoc_insertion_point(class_scope:uda.SignalRequest)
  })
_sym_db.RegisterMessage(SignalRequest)

SignalResponse = _reflection.GeneratedProtocolMessageType('SignalResponse', (_message.Message,), {
  'DESCRIPTOR' : _SIGNALRESPONSE,
  '__module__' : 'uda_pb2'
  # @@protoc_insertion_point(class_scope:uda.SignalResponse)
  })
_sym_db.RegisterMessage(SignalResponse)

SignalByTimeRequest = _reflection.GeneratedProtocolMessageType('SignalByTimeRequest', (_message.Message,), {
  'DESCRIPTOR' : _SIGNALBYTIMEREQUEST,
  '__module__' : 'uda_pb2'
  # @@protoc_insertion_point(class_scope:uda.SignalByTimeRequest)
  })
_sym_db.RegisterMessage(SignalByTimeRequest)

SignalByTimeResponse = _reflection.GeneratedProtocolMessageType('SignalByTimeResponse', (_message.Message,), {
  'DESCRIPTOR' : _SIGNALBYTIMERESPONSE,
  '__module__' : 'uda_pb2'
  # @@protoc_insertion_point(class_scope:uda.SignalByTimeResponse)
  })
_sym_db.RegisterMessage(SignalByTimeResponse)

SignalListRequest = _reflection.GeneratedProtocolMessageType('SignalListRequest', (_message.Message,), {
  'DESCRIPTOR' : _SIGNALLISTREQUEST,
  '__module__' : 'uda_pb2'
  # @@protoc_insertion_point(class_scope:uda.SignalListRequest)
  })
_sym_db.RegisterMessage(SignalListRequest)

SignalListItem = _reflection.GeneratedProtocolMessageType('SignalListItem', (_message.Message,), {
  'DESCRIPTOR' : _SIGNALLISTITEM,
  '__module__' : 'uda_pb2'
  # @@protoc_insertion_point(class_scope:uda.SignalListItem)
  })
_sym_db.RegisterMessage(SignalListItem)

SignalListResponse = _reflection.GeneratedProtocolMessageType('SignalListResponse', (_message.Message,), {
  'DESCRIPTOR' : _SIGNALLISTRESPONSE,
  '__module__' : 'uda_pb2'
  # @@protoc_insertion_point(class_scope:uda.SignalListResponse)
  })
_sym_db.RegisterMessage(SignalListResponse)

SignalMetaRequest = _reflection.GeneratedProtocolMessageType('SignalMetaRequest', (_message.Message,), {
  'DESCRIPTOR' : _SIGNALMETAREQUEST,
  '__module__' : 'uda_pb2'
  # @@protoc_insertion_point(class_scope:uda.SignalMetaRequest)
  })
_sym_db.RegisterMessage(SignalMetaRequest)

SignalDetail = _reflection.GeneratedProtocolMessageType('SignalDetail', (_message.Message,), {
  'DESCRIPTOR' : _SIGNALDETAIL,
  '__module__' : 'uda_pb2'
  # @@protoc_insertion_point(class_scope:uda.SignalDetail)
  })
_sym_db.RegisterMessage(SignalDetail)

SignalMetaResponse = _reflection.GeneratedProtocolMessageType('SignalMetaResponse', (_message.Message,), {
  'DESCRIPTOR' : _SIGNALMETARESPONSE,
  '__module__' : 'uda_pb2'
  # @@protoc_insertion_point(class_scope:uda.SignalMetaResponse)
  })
_sym_db.RegisterMessage(SignalMetaResponse)

Empty = _reflection.GeneratedProtocolMessageType('Empty', (_message.Message,), {
  'DESCRIPTOR' : _EMPTY,
  '__module__' : 'uda_pb2'
  # @@protoc_insertion_point(class_scope:uda.Empty)
  })
_sym_db.RegisterMessage(Empty)

SignalMonitorItem = _reflection.GeneratedProtocolMessageType('SignalMonitorItem', (_message.Message,), {
  'DESCRIPTOR' : _SIGNALMONITORITEM,
  '__module__' : 'uda_pb2'
  # @@protoc_insertion_point(class_scope:uda.SignalMonitorItem)
  })
_sym_db.RegisterMessage(SignalMonitorItem)

SignalMonitorResponse = _reflection.GeneratedProtocolMessageType('SignalMonitorResponse', (_message.Message,), {
  'DESCRIPTOR' : _SIGNALMONITORRESPONSE,
  '__module__' : 'uda_pb2'
  # @@protoc_insertion_point(class_scope:uda.SignalMonitorResponse)
  })
_sym_db.RegisterMessage(SignalMonitorResponse)

SignalMonitorByTimeRequest = _reflection.GeneratedProtocolMessageType('SignalMonitorByTimeRequest', (_message.Message,), {
  'DESCRIPTOR' : _SIGNALMONITORBYTIMEREQUEST,
  '__module__' : 'uda_pb2'
  # @@protoc_insertion_point(class_scope:uda.SignalMonitorByTimeRequest)
  })
_sym_db.RegisterMessage(SignalMonitorByTimeRequest)

SignalMonitorByTimeResponse = _reflection.GeneratedProtocolMessageType('SignalMonitorByTimeResponse', (_message.Message,), {
  'DESCRIPTOR' : _SIGNALMONITORBYTIMERESPONSE,
  '__module__' : 'uda_pb2'
  # @@protoc_insertion_point(class_scope:uda.SignalMonitorByTimeResponse)
  })
_sym_db.RegisterMessage(SignalMonitorByTimeResponse)

SignalMonitorTableColumn = _reflection.GeneratedProtocolMessageType('SignalMonitorTableColumn', (_message.Message,), {
  'DESCRIPTOR' : _SIGNALMONITORTABLECOLUMN,
  '__module__' : 'uda_pb2'
  # @@protoc_insertion_point(class_scope:uda.SignalMonitorTableColumn)
  })
_sym_db.RegisterMessage(SignalMonitorTableColumn)

SignalMonitorStructItem = _reflection.GeneratedProtocolMessageType('SignalMonitorStructItem', (_message.Message,), {
  'DESCRIPTOR' : _SIGNALMONITORSTRUCTITEM,
  '__module__' : 'uda_pb2'
  # @@protoc_insertion_point(class_scope:uda.SignalMonitorStructItem)
  })
_sym_db.RegisterMessage(SignalMonitorStructItem)

SignalMonitorStructResponse = _reflection.GeneratedProtocolMessageType('SignalMonitorStructResponse', (_message.Message,), {
  'DESCRIPTOR' : _SIGNALMONITORSTRUCTRESPONSE,
  '__module__' : 'uda_pb2'
  # @@protoc_insertion_point(class_scope:uda.SignalMonitorStructResponse)
  })
_sym_db.RegisterMessage(SignalMonitorStructResponse)

LoginRequest = _reflection.GeneratedProtocolMessageType('LoginRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOGINREQUEST,
  '__module__' : 'uda_pb2'
  # @@protoc_insertion_point(class_scope:uda.LoginRequest)
  })
_sym_db.RegisterMessage(LoginRequest)

LoginResponse = _reflection.GeneratedProtocolMessageType('LoginResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOGINRESPONSE,
  '__module__' : 'uda_pb2'
  # @@protoc_insertion_point(class_scope:uda.LoginResponse)
  })
_sym_db.RegisterMessage(LoginResponse)


DESCRIPTOR._options = None

_EXPERIMENT = _descriptor.ServiceDescriptor(
  name='Experiment',
  full_name='uda.Experiment',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1649,
  serialized_end=1785,
  methods=[
  _descriptor.MethodDescriptor(
    name='Signal',
    full_name='uda.Experiment.Signal',
    index=0,
    containing_service=None,
    input_type=_SIGNALREQUEST,
    output_type=_SIGNALRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SignalByTime',
    full_name='uda.Experiment.SignalByTime',
    index=1,
    containing_service=None,
    input_type=_SIGNALBYTIMEREQUEST,
    output_type=_SIGNALBYTIMERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_EXPERIMENT)

DESCRIPTOR.services_by_name['Experiment'] = _EXPERIMENT


_META = _descriptor.ServiceDescriptor(
  name='Meta',
  full_name='uda.Meta',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1788,
  serialized_end=1924,
  methods=[
  _descriptor.MethodDescriptor(
    name='SignalList',
    full_name='uda.Meta.SignalList',
    index=0,
    containing_service=None,
    input_type=_SIGNALLISTREQUEST,
    output_type=_SIGNALLISTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SingalMeta',
    full_name='uda.Meta.SingalMeta',
    index=1,
    containing_service=None,
    input_type=_SIGNALMETAREQUEST,
    output_type=_SIGNALMETARESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_META)

DESCRIPTOR.services_by_name['Meta'] = _META


_PROJECT = _descriptor.ServiceDescriptor(
  name='Project',
  full_name='uda.Project',
  file=DESCRIPTOR,
  index=2,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1927,
  serialized_end=2158,
  methods=[
  _descriptor.MethodDescriptor(
    name='SignalMonitor',
    full_name='uda.Project.SignalMonitor',
    index=0,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_SIGNALMONITORRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SignalMonitorByTime',
    full_name='uda.Project.SignalMonitorByTime',
    index=1,
    containing_service=None,
    input_type=_SIGNALMONITORBYTIMEREQUEST,
    output_type=_SIGNALMONITORBYTIMERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SignalMonitorStruct',
    full_name='uda.Project.SignalMonitorStruct',
    index=2,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_SIGNALMONITORSTRUCTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PROJECT)

DESCRIPTOR.services_by_name['Project'] = _PROJECT


_USER = _descriptor.ServiceDescriptor(
  name='User',
  full_name='uda.User',
  file=DESCRIPTOR,
  index=3,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2160,
  serialized_end=2216,
  methods=[
  _descriptor.MethodDescriptor(
    name='Login',
    full_name='uda.User.Login',
    index=0,
    containing_service=None,
    input_type=_LOGINREQUEST,
    output_type=_LOGINRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_USER)

DESCRIPTOR.services_by_name['User'] = _USER

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import uda_pb2 as uda__pb2


class ExperimentStub(object):
    """实验数据（诊断数据）接口
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Signal = channel.unary_unary(
                '/uda.Experiment/Signal',
                request_serializer=uda__pb2.SignalRequest.SerializeToString,
                response_deserializer=uda__pb2.SignalResponse.FromString,
                )
        self.SignalByTime = channel.unary_unary(
                '/uda.Experiment/SignalByTime',
                request_serializer=uda__pb2.SignalByTimeRequest.SerializeToString,
                response_deserializer=uda__pb2.SignalByTimeResponse.FromString,
                )


class ExperimentServicer(object):
    """实验数据（诊断数据）接口
    """

    def Signal(self, request, context):
        """获取诊断数据信号
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SignalByTime(self, request, context):
        """根据起止时间获取诊断信号
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ExperimentServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Signal': grpc.unary_unary_rpc_method_handler(
                    servicer.Signal,
                    request_deserializer=uda__pb2.SignalRequest.FromString,
                    response_serializer=uda__pb2.SignalResponse.SerializeToString,
            ),
            'SignalByTime': grpc.unary_unary_rpc_method_handler(
                    servicer.SignalByTime,
                    request_deserializer=uda__pb2.SignalByTimeRequest.FromString,
                    response_serializer=uda__pb2.SignalByTimeResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'uda.Experiment', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Experiment(object):
    """实验数据（诊断数据）接口
    """

    @staticmethod
    def Signal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/uda.Experiment/Signal',
            uda__pb2.SignalRequest.SerializeToString,
            uda__pb2.SignalResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SignalByTime(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/uda.Experiment/SignalByTime',
            uda__pb2.SignalByTimeRequest.SerializeToString,
            uda__pb2.SignalByTimeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class MetaStub(object):
    """检索数据(元数据)接口
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SignalList = channel.unary_unary(
                '/uda.Meta/SignalList',
                request_serializer=uda__pb2.SignalListRequest.SerializeToString,
                response_deserializer=uda__pb2.SignalListResponse.FromString,
                )
        self.SingalMeta = channel.unary_unary(
                '/uda.Meta/SingalMeta',
                request_serializer=uda__pb2.SignalMetaRequest.SerializeToString,
                response_deserializer=uda__pb2.SignalMetaResponse.FromString,
                )


class MetaServicer(object):
    """检索数据(元数据)接口
    """

    def SignalList(self, request, context):
        """获取诊断信号列表
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SingalMeta(self, request, context):
        """获取诊断数据元数据
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MetaServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SignalList': grpc.unary_unary_rpc_method_handler(
                    servicer.SignalList,
                    request_deserializer=uda__pb2.SignalListRequest.FromString,
                    response_serializer=uda__pb2.SignalListResponse.SerializeToString,
            ),
            'SingalMeta': grpc.unary_unary_rpc_method_handler(
                    servicer.SingalMeta,
                    request_deserializer=uda__pb2.SignalMetaRequest.FromString,
                    response_serializer=uda__pb2.SignalMetaResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'uda.Meta', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Meta(object):
    """检索数据(元数据)接口
    """

    @staticmethod
    def SignalList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/uda.Meta/SignalList',
            uda__pb2.SignalListRequest.SerializeToString,
            uda__pb2.SignalListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SingalMeta(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/uda.Meta/SingalMeta',
            uda__pb2.SignalMetaRequest.SerializeToString,
            uda__pb2.SignalMetaResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class ProjectStub(object):
    """工程数据接口
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SignalMonitor = channel.unary_unary(
                '/uda.Project/SignalMonitor',
                request_serializer=uda__pb2.Empty.SerializeToString,
                response_deserializer=uda__pb2.SignalMonitorResponse.FromString,
                )
        self.SignalMonitorByTime = channel.unary_unary(
                '/uda.Project/SignalMonitorByTime',
                request_serializer=uda__pb2.SignalMonitorByTimeRequest.SerializeToString,
                response_deserializer=uda__pb2.SignalMonitorByTimeResponse.FromString,
                )
        self.SignalMonitorStruct = channel.unary_unary(
                '/uda.Project/SignalMonitorStruct',
                request_serializer=uda__pb2.Empty.SerializeToString,
                response_deserializer=uda__pb2.SignalMonitorStructResponse.FromString,
                )


class ProjectServicer(object):
    """工程数据接口
    """

    def SignalMonitor(self, request, context):
        """获取当前的工程数据
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SignalMonitorByTime(self, request, context):
        """按照时间段获取工程数据
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SignalMonitorStruct(self, request, context):
        """获取工程监控数据存储结构
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProjectServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SignalMonitor': grpc.unary_unary_rpc_method_handler(
                    servicer.SignalMonitor,
                    request_deserializer=uda__pb2.Empty.FromString,
                    response_serializer=uda__pb2.SignalMonitorResponse.SerializeToString,
            ),
            'SignalMonitorByTime': grpc.unary_unary_rpc_method_handler(
                    servicer.SignalMonitorByTime,
                    request_deserializer=uda__pb2.SignalMonitorByTimeRequest.FromString,
                    response_serializer=uda__pb2.SignalMonitorByTimeResponse.SerializeToString,
            ),
            'SignalMonitorStruct': grpc.unary_unary_rpc_method_handler(
                    servicer.SignalMonitorStruct,
                    request_deserializer=uda__pb2.Empty.FromString,
                    response_serializer=uda__pb2.SignalMonitorStructResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'uda.Project', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Project(object):
    """工程数据接口
    """

    @staticmethod
    def SignalMonitor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/uda.Project/SignalMonitor',
            uda__pb2.Empty.SerializeToString,
            uda__pb2.SignalMonitorResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SignalMonitorByTime(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/uda.Project/SignalMonitorByTime',
            uda__pb2.SignalMonitorByTimeRequest.SerializeToString,
            uda__pb2.SignalMonitorByTimeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SignalMonitorStruct(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/uda.Project/SignalMonitorStruct',
            uda__pb2.Empty.SerializeToString,
            uda__pb2.SignalMonitorStructResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class UserStub(object):
    """用户接口
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Login = channel.unary_unary(
                '/uda.User/Login',
                request_serializer=uda__pb2.LoginRequest.SerializeToString,
                response_deserializer=uda__pb2.LoginResponse.FromString,
                )


class UserServicer(object):
    """用户接口
    """

    def Login(self, request, context):
        """用户登录
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UserServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Login': grpc.unary_unary_rpc_method_handler(
                    servicer.Login,
                    request_deserializer=uda__pb2.LoginRequest.FromString,
                    response_serializer=uda__pb2.LoginResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'uda.User', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class User(object):
    """用户接口
    """

    @staticmethod
    def Login(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/uda.User/Login',
            uda__pb2.LoginRequest.SerializeToString,
            uda__pb2.LoginResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# !/usr/bin/env python
# -*- coding: UTF-8 -*-

from setuptools import setup, find_packages

setup(
    name='udarpc',
    version='0.0.1',
    author='memory shen',
    author_email='zhengyang.shen@ipp.ac.cn',
    description=u'uda rpc python client lib',
    license="MIT",
    packages=find_packages(),
    url='https://packaging.python.org/',
    include_package_data=True,
    classifiers=[
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Programming Language :: Python :: 3.6',
    ],
    install_requires=[
            'numpy>=1.19.2'
    ],
)
